@@ -4,14 +4,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-01-01'; # DATE
+our $DATE = '2024-02-01'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20240101.0'; # VERSION
+our $VERSION = '20240201.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
-    'JGNI' => '',
-    'MIKKOI' => '',
     'PERLANCAR' => '',
+    'DERIV' => '',
+    'LEONT' => '',
 );
 
 
@@ -30,20 +30,20 @@ Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current - Authors with
 
 =head1 VERSION
 
-This document describes version 20240101.0 of Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-01-01.
+This document describes version 20240201.0 of Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-02-01.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2024-01-01, produced by L<cpan-streaks>):
+Current standings (as of 2024-02-01, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | JGNI      |   2 | 2023-12-31 | ongoing     |
-  | MIKKOI    |   1 | 2023-12-31 | might-break |
-  | PERLANCAR |   1 | 2023-12-31 | might-break |
+  | PERLANCAR |  24 | 2024-01-09 | ongoing     |
+  | DERIV     |   1 | 2024-01-31 | might-break |
+  | LEONT     |   1 | 2024-01-31 | might-break |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
